==> apilama-0.1.6.tar.gz: apilama-0.1.6/apilama/routes/pylama_routes.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
PyLama API Routes

This module provides Flask routes for interacting with the PyLama service.
"""

from flask import Blueprint, request, jsonify, current_app
from apilama.logger import logger

# Create a blueprint for PyLama routes
pylama_routes = Blueprint('pylama_routes', __name__)


@pylama_routes.route('/api/pylama/health', methods=['GET'])
def health_check():
    """Health check endpoint for PyLama service.
    
    Returns:
        JSON response with the status of the PyLama service
    """
    logger.info('PyLama health check')
    
    # TODO: Implement actual health check for PyLama service
    return jsonify({
        'status': 'ok',
        'service': 'pylama'
    })


@pylama_routes.route('/api/pylama/execute', methods=['POST'])
def execute_code():
    """Execute code using PyLama.
    
    Returns:
        JSON response with the execution results
    """
    data = request.get_json()
    
    if not data or 'code' not in data:
        logger.error('Invalid request: No code provided')
        return jsonify({
            'status': 'error',
            'message': 'No code provided'
        }), 400
    
    code = data['code']
    logger.info(f'Executing code with PyLama')
    
    # TODO: Implement actual code execution with PyLama
    # This is a placeholder for the actual implementation
    result = {
        'status': 'success',
        'output': f'Executed code: {code[:50]}...' if len(code) > 50 else f'Executed code: {code}',
        'execution_time': 0.1
    }
    
    return jsonify(result)

==> apilama-0.1.9.tar.gz: apilama-0.1.9/apilama/routes/pylama_routes.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
PyLama API Routes

This module provides Flask routes for interacting with the PyLama service.
"""

from flask import Blueprint, request, jsonify, current_app
from apilama.logger import logger

# Create a blueprint for PyLama routes
devlama_routes = Blueprint('devlama_routes', __name__)


@devlama_routes.route('/api/devlama/health', methods=['GET'])
def health_check():
    """Health check endpoint for PyLama service.
    
    Returns:
        JSON response with the status of the PyLama service
    """
    logger.info('PyLama health check')
    
    # TODO: Implement actual health check for PyLama service
    return jsonify({
        'status': 'ok',
        'service': 'devlama'
    })


@devlama_routes.route('/api/devlama/execute', methods=['POST'])
def execute_code():
    """Execute code using PyLama.
    
    Returns:
        JSON response with the execution results
    """
    data = request.get_json()
    
    if not data or 'code' not in data:
        logger.error('Invalid request: No code provided')
        return jsonify({
            'status': 'error',
            'message': 'No code provided'
        }), 400
    
    code = data['code']
    logger.info(f'Executing code with PyLama')
    
    # TODO: Implement actual code execution with PyLama
    # This is a placeholder for the actual implementation
    result = {
        'status': 'success',
        'output': f'Executed code: {code[:50]}...' if len(code) > 50 else f'Executed code: {code}',
        'execution_time': 0.1
    }
    
    return jsonify(result)
